@@ -26,6 +26,10 @@ from pytube import YouTube
 class crawl:
     
     def __init__(self,video_name:str="",video_id:str="",output: str = "",video_link:str=''):
+        if " " in video_name:
+            video_name=video_name.split()
+            video_name="+".join(video_name)
+            
         self.name = video_name
         
         self.id = video_id
@@ -52,7 +56,7 @@ class crawl:
     
         session = HTMLSession()
         response = session.get(self.link2)
-        response.html.render(sleep=1)
+        response.html.render(sleep=4)
         self.soup = BeautifulSoup(response.html.html, "html.parser") 
     
     
@@ -95,7 +99,7 @@ class crawl:
     def likes_dislikes(self):
         session = HTMLSession()
         response = session.get(self.link2)
-        response.html.render(sleep=1)
+        response.html.render(sleep=4)
         soup = BeautifulSoup(response.html.html, "html.parser")
         likes_dislikes=[]
         for i in soup.find_all("yt-formatted-string",{"id":"text"}):
